@@ -21,8 +21,8 @@
 #include <tqregexp.h>
 #include <tqtimer.h>
 
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kurl.h>
 
 #include "kileconfig.h"
